pub type RustAutoOpaque<T> = RustAutoOpaqueBase<T, MoiArc<RustAutoOpaqueInner<T>>>;
Usually this is unneeded, and just write down arbitrary types. However, when you need arbitrary types at places that are not supported yet, use RustOpaqueOpaque<YourArbitraryType>.

Aliased Type

struct RustAutoOpaque<T> {
    arc: MoiArc<RustAutoOpaqueInner<T>>,
    _phantom: PhantomData<RustAutoOpaqueInner<T>>,
}

Fields

arc: MoiArc<RustAutoOpaqueInner<T>>_phantom: PhantomData<RustAutoOpaqueInner<T>>