Type Alias rust_lib_flutter_test_gui::frb_generated::RustAutoOpaque
source · pub type RustAutoOpaque<T> = RustAutoOpaqueBase<T, MoiArc<RustAutoOpaqueInner<T>>>;Expand description
Usually this is unneeded, and just write down arbitrary types.
However, when you need arbitrary types at places that are not supported yet,
use RustOpaqueOpaque<YourArbitraryType>.
Aliased Type
struct RustAutoOpaque<T> {
arc: MoiArc<RustAutoOpaqueInner<T>>,
_phantom: PhantomData<RustAutoOpaqueInner<T>>,
}Fields
arc: MoiArc<RustAutoOpaqueInner<T>>_phantom: PhantomData<RustAutoOpaqueInner<T>>